/***************************************************************************
 * jtalk -- talk-like Jabber client
 * (C) Nicolas George - 2006
 * settings.c: user settings handling
 ***************************************************************************/

/*
  This file is part of jtalk.

  jtalk is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  jtalk is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with jtalk; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <glib.h>

const char *jtalk_user;

const char *jtalk_esc_reset = "\033[m";
const char *jtalk_esc_error = "\033[31m";
const char *jtalk_esc_name = "\033[36;1m";
const char *jtalk_esc_self_name = "\033[33;1m";

const size_t jtalk_opt_max_history = 1024 * 1024;

static char *jtalk_base;

void
jtalk_settings_init(void)
{
    char *home;

    if((jtalk_base = getenv("JTALK_BASE")) != NULL) {
	jtalk_base = g_strdup(jtalk_base);
    } else {
	if((home = getenv("HOME")) == NULL) {
	    fprintf(stderr, "No $HOME nor $JTALK_BASE.\n");
	    exit(1);
	}
	jtalk_base = g_strdup_printf("%s/%s", home, ".jtalk");
    }

    if((jtalk_user = getenv("USER")) == NULL) {
	/* TODO: getpwuid(getuid()) */
	abort();
    }
}

char *
jtalk_settings_get_file(const char *path)
{
    if(path == NULL)
	return(jtalk_base);
    return(g_strdup_printf("%s/%s", jtalk_base, path));
}
